from ..config.app_config import AppConfig as AppConfig
from .base.snowflake import SnowflakeGenerator as SnowflakeGenerator
from _typeshed import Incomplete

class GenerateUniqueIDUtil:
    def __new__(cls, *args, **kwargs): ...
    generator: Incomplete
    def __load__(self) -> None: ...
    def generate_id(self) -> int | None: ...

generate_unique_util: Incomplete

def get_primary_id() -> int | None: ...
def get_primary_str() -> str | None: ...
